# coding: utf-8

# flake8: noqa

"""
    CATAPA API

    # Introduction CATAPA API uses RESTful API style. It uses JSON data format for data exchange and utilizes HTTP verbs as appropriate.  For authorization & authentication, CATAPA API uses OAuth 2.0 protocol.  # Base URL Production: https://api.catapa.com  # Authentication Clients need to acquire an access token before they send HTTP requests to resource endpoints.  <SecurityDefinitions />  ## Validate Access Token    Use this endpoint to verify if an access token is valid and was issued by the API gateway. The endpoint supports both user tokens and client credentials tokens.    | **HTTP Method**  | `GET`                                                |                                         |   |------------------|------------------------------------------------------|-----------------------------------------|   | **URL**          | `<base-url>/v1/oauth-clients/validate-access-token`  |                                         |   | **Headers**      | `Authorization`                                      | `Bearer <access-token>`                 |   |                  | `Tenant`                                             | Your tenant identifier (e.g., \"catapa\") |  ### Example request using `curl`    ```bash   curl --location '<base-url>/v1/oauth-clients/validate-access-token' \\     --header 'Tenant: catapa' \\     --header 'Authorization: Bearer <access-token>'   ```  ### Response codes  - **200 OK**: Token is valid - **401 Unauthorized**: Token is invalid or expired  ### Notes  - This endpoint validates both user authentication tokens and client credentials tokens - For server-to-server communication, use client credentials flow with the token in the Authorization header - No response body is returned; the status code indicates the validation result - The `Tenant` header is required to specify which tenant context to validate the token against  # HTTP Headers Each request should contain the following headers.  |Headers        |Description  | |---------------|-------------| |Tenant         |Tenant name. e.g. Catapa| |Authorization  |For authentication. Value format: Bearer <access-token>|  Example HTTP Request using cURL: ```bash curl <base-url>/core/v1/employees?page=0&size=10 \\ -H \"Tenant: <tenant name>\" \\ -H \"Authorization: Bearer <access-token>\" ```  # Rate Limit To ensure optimal API performance and fair usage for all users, we implement rate limiting. The general limit is **400 requests per minute, per Client ID**. If you exceed the rate limit, you will receive an HTTP 429 (Too Many Requests) error response.  # Pagination The API provides `page` & `size` query params. `page` is a page number starting from 0. `size` is number of elements per page. Maximum value of `size` is 50.  Every paginated endpoints will have following response format: ``` {   \"content\": [     { ... },     { ... }   ],   \"number\": 0, // page number   \"size\": 10, // page size   \"numberOfElements\": 10, // number of element in this current page   \"totalElements\": 100,   \"totalPages\": 10 } ```  # Search Query You can perform search operations in some endpoints by setting the query parameter. Query value parameter constructed with following format:  ```bash ?query=<key><operator><value>,<key><operator><value> ```  Explanations: | Format | Descriptions | |-|-| | `<key>` | Key name to search certain fields | | `<operator>`   | Operation to apply on certain fields.<br>Supported operators: `:` `<` `>` | | `<value>` | Value to apply on search. **Value should be encoded using URL encoder**. For examples:<br><br>Plain: `John Doe`<br>Encoded: `John%20Doe` | | `,` | AND operator |   For example, the `/core/v1/employees` endpoint has following search query. |Key                    |Supported Operators  |Notes  | |-----------------------|---------------------|-------| |identificationNumberIn | `:`                 |Equal operator with multiple values. Each value should separated with delimiters `;`| |name                   | `:`                 |Like operator| |startDate              | `:`<br/>`>`<br/>`<` |Equal<br>Greater than or equal to<br>Less than or equal to|  Clients can construct search query with these following variations:  1. Search an employee with ID number 1111 ```bash curl <base-url>/core/v1/employees?query=identificationNumberIn:1111 ``` 1. Search multiple employees with ID number 1111 and 2222 ```bash curl <base-url>/core/v1/employees?query=identificationNumberIn:1111;2222 ``` 1. Search employees with name `John Doe` ```bash curl <base-url>/core/v1/employees?query=name:John%20Doe ``` 1. Search all employees with start date between 2020-01-01 and 2020-12-31: ```bash curl <base-url>/core/v1/employees?query=startDate>2020-01-01,startDate<2020-12-31 ``` 

    The version of the OpenAPI document: 1.0.0
    Contact: support@catapa.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


__version__ = "1.0.0"

# Define package exports
__all__ = [
    "AnalyticsApi",
    "AnomalyDetectionApi",
    "BankAccountConfigurationApi",
    "BpjsHealthcareApi",
    "BpjsManpowerApi",
    "CompanyBankAccountApi",
    "ContactInformationApi",
    "CustomTableApi",
    "CustomTableEntryApi",
    "EditableSalaryPreprocessApi",
    "EmployeeApi",
    "EmployeeBankAccountConfigurationApi",
    "EmployeeBpjsMembershipApi",
    "EmployeeDetailApi",
    "EmployeePaygroupApi",
    "EmployeePaymentItemGroupSequenceApi",
    "EmployeeSalaryTemplateApi",
    "EmployeeVariableApi",
    "EmploymentStatusApi",
    "FamiliesApi",
    "FormerEmployeeIncomeApi",
    "IdentityCardsApi",
    "MasterDataApi",
    "OauthClientApi",
    "OrganizationApi",
    "PaygroupApi",
    "PayrollOthersApi",
    "PayrollProcessSnapshotApi",
    "PayslipApi",
    "RoleApi",
    "SalaryCalculationApi",
    "SalaryItemApi",
    "SalaryPaymentApi",
    "SalaryTemplateApi",
    "SeveranceApi",
    "TaxApi",
    "TaxMembershipApi",
    "TaxMembershipHistoryApi",
    "TerminationApi",
    "TimeManagementApi",
    "TransitionCalculationApi",
    "UserApi",
    "WidgetsApi",
    "WorkflowApi",
    "ApiResponse",
    "ApiClient",
    "Configuration",
    "OpenApiException",
    "ApiTypeError",
    "ApiValueError",
    "ApiKeyError",
    "ApiAttributeError",
    "ApiException",
    "AdditionalAssignmentApprovalPageResponse",
    "AdditionalAssignmentApprovalResponse",
    "AdditionalAssignmentApprovaleSubLocationResponse",
    "AdditionalAssignmentResponse",
    "AdditionalFamilyMembershipResponse",
    "AdditionalIncomePaymentListItemResponse",
    "AdditionalIncomePaymentPageResponse",
    "AddressDetailResponse",
    "AmountRequest",
    "AnalyticsChartDataResponse",
    "AnalyticsChartDataSeriesResponse",
    "AnalyticsChartPageResponse",
    "AnalyticsChartRequest",
    "AnalyticsChartResponse",
    "AnalyticsColorSchemeDetailResponse",
    "AnalyticsColorSchemeResponse",
    "AnalyticsColumnResponse",
    "AnnualTaxCalculationSimulatorMonthlyTaxReportsResponse",
    "AnnualTaxCalculationSimulatorRequest",
    "AnnualTaxCalculationSimulatorResponse",
    "AnnualTaxCalculationSimulatorResultResponse",
    "AnomalySuspectAttributeResponse",
    "AnomalySuspectAttributeValueChildResponse",
    "AnomalySuspectAttributeValueResponse",
    "AnomalySuspectFileResponse",
    "AnomalySuspectPageResponse",
    "AnomalySuspectResponse",
    "AttendanceItemResponse",
    "AttendancePageResponse",
    "AttendanceRecapitulationDetailAttendanceItemResponse",
    "AttendanceRecapitulationDetailItemResponse",
    "AttendanceRecapitulationDetailOvertimeResponse",
    "AttendanceRecapitulationDetailPageResponse",
    "AttendanceStatusResponse",
    "AuthorityDetailResponse",
    "BankAccountConfigurationPageResponse",
    "BankAccountConfigurationRequest",
    "BankAccountConfigurationResponse",
    "BankAccountConfigurationResponseSource",
    "BankAccountResponse",
    "BankBranchPageResponse",
    "BankBranchResponse",
    "BankBranchSimpleResponse",
    "BankPageResponse",
    "BankResponse",
    "BpjsHealthcareCurrentMonthDetailResponse",
    "BpjsHealthcareMembershipAdditionalFamilyMembership",
    "BpjsHealthcareMembershipRequest",
    "BpjsHealthcareMembershipResponse",
    "BpjsHealthcarePremiumDetailsItemResponse",
    "BpjsHealthcarePremiumDetailsResponse",
    "BpjsHealthcarePremiumSummaryListItemResponse",
    "BpjsHealthcarePremiumSummaryPageResponse",
    "BpjsHealthcareProviderListItemResponse",
    "BpjsHealthcareProviderPageResponse",
    "BpjsHealthcareTemplateListItemResponse",
    "BpjsHealthcareTemplatePageResponse",
    "BpjsHealthcareTreatmentClassResponse",
    "BpjsManpowerCurrentMonthDetailResponse",
    "BpjsManpowerMembershipRequest",
    "BpjsManpowerMembershipResponse",
    "BpjsManpowerPremiumDetailsItemResponse",
    "BpjsManpowerPremiumDetailsResponse",
    "BpjsManpowerPremiumSummaryListItemResponse",
    "BpjsManpowerPremiumSummaryPageResponse",
    "BpjsManpowerProviderPageResponse",
    "BpjsManpowerProviderResponse",
    "BpjsManpowerTemplatePageResponse",
    "BpjsManpowerTemplateResponse",
    "BulkOperationFailureParamResponse",
    "BulkOperationFailureResponse",
    "BulkOperationResponse",
    "CalculationScenarioComponent",
    "CalculationScenarioPreviousJobComponent",
    "CalculationScenarioSalaryComponent",
    "ChartFilterRequest",
    "ChartFilterResponse",
    "ChartTableRelationRequest",
    "ChartTableRelationResponse",
    "ChartValueCollectionFilterRequest",
    "CityPageResponse",
    "CityResponse",
    "CompanyBankAccountPageResponse",
    "CompanyBankAccountResponse",
    "CompanyDetailRequest",
    "CompanyDetailResponse",
    "CompanyDetailTimeZoneRequest",
    "CompanyGroupPageResponse",
    "CompanyListItemResponse",
    "CompanyPageResponse",
    "CompanySuperiorResponse",
    "ContactInformationPageResponse",
    "ContactInformationRequest",
    "ContactInformationResponse",
    "CostCenterListItemResponse",
    "CostCenterPageResponse",
    "CostCenterRequest",
    "CostCenterResponse",
    "CostCenterSimpleResponse",
    "CountResponse",
    "CountryPageResponse",
    "CountryRequest",
    "CountryResponse",
    "CreateCityRequest",
    "CreateCityRequestState",
    "CurrencyPageResponse",
    "CurrencyResponse",
    "CurrencySimpleResponse",
    "CustomTableColumnResponse",
    "CustomTableEntryPageResponse",
    "CustomTablePageResponse",
    "CustomTableResponse",
    "EditableSalaryPreprocessRequest",
    "EditableSalaryPreprocessResponse",
    "EditableSalaryPreprocessSuccess",
    "EducationLevelPageResponse",
    "EducationLevelResponse",
    "EducationPageResponse",
    "EducationResponse",
    "EmergencyContactResponse",
    "EmployeeCreateResponse",
    "EmployeeDetailPageResponse",
    "EmployeeDetailRequest",
    "EmployeeDetailResponse",
    "EmployeeFullResponse",
    "EmployeeHiringDataRequest",
    "EmployeeHiringDataResponse",
    "EmployeeHiringDataSimpleResponse",
    "EmployeeIdIdentificationNumberResponse",
    "EmployeeIdNameResponse",
    "EmployeeIdentificationNumberResponse",
    "EmployeeIdentityCardPageResponse",
    "EmployeeIdentityCardRequest",
    "EmployeeIdentityCardResponse",
    "EmployeeManagerResponse",
    "EmployeePageResponse",
    "EmployeePaygroupPageResponse",
    "EmployeePaygroupResponse",
    "EmployeeRequest",
    "EmployeeResponse",
    "EmployeeSalaryRequest",
    "EmployeeSalaryResponse",
    "EmployeeSalaryTemplatePageResponse",
    "EmployeeSalaryTemplateRequest",
    "EmployeeSalaryTemplateResponse",
    "EmployeeSalaryTemplateUpdateResponse",
    "EmployeeSimpleResponse",
    "EmployeeVariableMetadataPageResponse",
    "EmployeeVariableMetadataRequest",
    "EmployeeVariableMetadataResponse",
    "EmployeeVariablePageResponse",
    "EmployeeVariableRequest",
    "EmployeeVariableResponse",
    "EmployeeVariableValidationRequest",
    "EmployeeVariableValidationResponse",
    "EmployeeWorkdayConfigurationPageResponse",
    "EmployeeWorkdayConfigurationRequest",
    "EmployeeWorkdayConfigurationResponse",
    "EmploymentDataPositionResponse",
    "EmploymentDataRequest",
    "EmploymentDataResponse",
    "EmploymentStatusDetailPositionResponse",
    "EmploymentStatusDetailResponse",
    "EmploymentStatusHistoryDetailResponse",
    "EmploymentStatusHistoryPageResponse",
    "EmploymentStatusPageResponse",
    "EmploymentStatusTypePageResponse",
    "EmploymentStatusTypeResponse",
    "EmploymentTypePageResponse",
    "EmploymentTypeRequest",
    "EmploymentTypeResponse",
    "ErrorResponse",
    "FamilyApprovalListItemResponse",
    "FamilyApprovalListItemWithApprovalStatusResponse",
    "FamilyApprovalPageResponse",
    "FamilyApprovalRequest",
    "FamilyApprovalResponse",
    "FamilyHistoricalPageResponse",
    "FamilyHistoricalResponse",
    "FamilyMemberRelationPageResponse",
    "FamilyMemberRelationResponse",
    "FieldOfStudyPageResponse",
    "FieldOfStudyResponse",
    "FingerprintFailureItemResponse",
    "FingerprintItemRequest",
    "FingerprintResponse",
    "FingerprintSuccessItemResponse",
    "FormerEmployeeIncomeEmployeeAmountUpdateRequest",
    "FormerEmployeeIncomeEmployeePageResponse",
    "FormerEmployeeIncomeEmployeeResponse",
    "FormerEmployeeIncomePageResponse",
    "FormerEmployeeIncomeResponse",
    "HolidayItemResponse",
    "HolidayPageResponse",
    "IdCodeNameResponse",
    "IdRequest",
    "IdResponse",
    "IdentityCardPageResponse",
    "IdentityCardResponse",
    "InstitutionPageResponse",
    "InstitutionResponse",
    "JobLevelPageResponse",
    "JobLevelRequest",
    "JobLevelResponse",
    "JobTitleLevelMappingPageResponse",
    "JobTitleLevelMappingResponse",
    "JobTitlePageResponse",
    "JobTitleRequest",
    "JobTitleRequestDeprecated",
    "JobTitleResponse",
    "JobTitleWithJobLevelsResponse",
    "KppPageResponse",
    "KppResponse",
    "KppSimpleResponse",
    "LeaveBalanceItemResponse",
    "LeaveBalancePageResponse",
    "LeaveBalanceRequest",
    "LocationCreateRequest",
    "LocationGroupPageResponse",
    "LocationPageResponse",
    "LocationResponse",
    "LogoFileMetadataResponse",
    "ManagerRequest",
    "MonthlyRecapitulationItemDetailResponse",
    "MonthlyRecapitulationItemResponse",
    "MonthlyRecapitulationPageResponse",
    "MonthlyTaxCalculationSimulatorRequest",
    "MonthlyTaxCalculationSimulatorResponse",
    "MonthlyTaxDetailPageResponse",
    "MonthlyTaxDetailResponse",
    "MonthlyTaxReportPageResponse",
    "MonthlyTaxReportResponse",
    "NameResponse",
    "NonEmployeeMonthlyTaxCalculationSimulatorResponse",
    "OAuthClientPageResponse",
    "OAuthClientResponse",
    "OperationalGroupPageResponse",
    "OrganizationGroupPageResponse",
    "OrganizationGroupRequest",
    "OrganizationHeadPageResponse",
    "OrganizationHeadResponse",
    "OrganizationHierarchyPageResponse",
    "OrganizationHierarchyRequest",
    "OrganizationHierarchyResponse",
    "OrganizationHistoryHierarchyResponse",
    "OrganizationHistoryPageResponse",
    "OrganizationHistoryResponse",
    "OrganizationPageResponse",
    "OrganizationParentResponse",
    "OrganizationRequest",
    "OrganizationResponse",
    "OrganizationSuperiorPageResponse",
    "OrganizationSuperiorResponse",
    "OtherLeaveBalanceCreateResponse",
    "OtherLeaveBalanceItemResponse",
    "OtherLeaveBalancePageResponse",
    "OtherLeaveBalanceRequest",
    "OtherLeaveStatusResponse",
    "Page",
    "PaygroupPageResponse",
    "PaygroupResponse",
    "PaymentItemDetailResponse",
    "PaymentItemDetailSalaryItemResponse",
    "PaymentItemGroupLastSequenceResponse",
    "PaymentItemGroupPageResponse",
    "PaymentItemGroupResponse",
    "PaymentItemGroupSequenceResponse",
    "PayrollProcessSnapshotBankAccountConfigurationResponse",
    "PayrollProcessSnapshotBankAccountResponse",
    "PayrollProcessSnapshotEmploymentStatusResponse",
    "PayrollProcessSnapshotPageResponse",
    "PayrollProcessSnapshotResponse",
    "PayrollProcessSnapshotWorkflowActivityResponse",
    "PayrollProcessSnapshotWorkflowReasonResponse",
    "PayrollProcessSnapshotWorkflowTemplateResponse",
    "PayslipAdditionalNotePageResponse",
    "PayslipAdditionalNoteRequest",
    "PayslipAdditionalNoteResponse",
    "PayslipDownloadRequest",
    "PayslipLayoutPageResponse",
    "PayslipLayoutRequest",
    "PayslipLayoutResponse",
    "PermanentMonthlyTaxCalculationSimulatorResponse",
    "PhotoResponse",
    "PlaceOfBirthRequest",
    "PlaceOfBirthResponse",
    "PointOfHireResponse",
    "PositionCostCenterPageResponse",
    "PositionCostCenterResponse",
    "PositionHistoryOrganizationResponse",
    "PositionHistoryPageResponse",
    "PositionHistoryResponse",
    "PositionListItemResponse",
    "PositionPageResponse",
    "PositionResponse",
    "PositionVacancyStatusPageResponse",
    "PositionVacancyStatusResponse",
    "Pph21PolicyResponse",
    "ProcessableTimeAllowanceTransitionEmployeeResponse",
    "ProcessableTimeAllowanceTransitionEmploymentStatusResponse",
    "ProcessableTimeAllowanceTransitionPageResponse",
    "ProcessableTimeAllowanceTransitionResponse",
    "ProcessedSalaryPaymentDetailResponse",
    "ProcessedSalaryPaymentPageResponse",
    "ProcessedSalaryPaymentResponse",
    "ProcessedTransitionCalculationPageResponse",
    "ProcessedTransitionCalculationResponse",
    "ProrateDetailResponse",
    "ProrateDetailSalaryTemplateDetailResponse",
    "ProrateDetailSalaryTemplateDetailSalaryItemResponse",
    "PtkpCategoryPageResponse",
    "PtkpCategoryResponse",
    "RecurringConfigurationRequest",
    "RecurringConfigurationResponse",
    "RecurringPeriodEndRequest",
    "RecurringPeriodEndResponse",
    "RejectApprovalRequest",
    "ReligionPageResponse",
    "ReligionRequest",
    "ReligionResponse",
    "RoleAuthorityPageResponse",
    "RoleAuthorityResponse",
    "RoleDetailResponse",
    "RoleIdNameResponse",
    "RolePageResponse",
    "RolePermissionPageResponse",
    "RolePermissionResponse",
    "RoleResponse",
    "SalaryCalculationDetailPageResponse",
    "SalaryCalculationDetailResponse",
    "SalaryCalculationPageResponse",
    "SalaryCalculationResponse",
    "SalaryItemAddOnEmployeeRequest",
    "SalaryItemAddOnEmployeeResponse",
    "SalaryItemAddOnRequest",
    "SalaryItemAddOnResponse",
    "SalaryItemAddOnSalaryItemRequest",
    "SalaryItemPageResponse",
    "SalaryItemResponse",
    "SalaryItemResponseWithCategory",
    "SalaryItemSimpleResponse",
    "SalaryItemWithSalaryItemTypeResponse",
    "SalaryPaymentDetailCompanyBankAccountResponse",
    "SalaryPaymentDetailResponse",
    "SalaryPaymentEmployeeResponse",
    "SalaryPaymentEmploymentStatusResponse",
    "SalaryPaymentPageResponse",
    "SalaryPaymentResponse",
    "SalaryPaymentSummaryCompanyBankAccountResponse",
    "SalaryPaymentSummaryPageResponse",
    "SalaryPaymentSummaryResponse",
    "SalaryTemplateDetailResponse",
    "SalaryTemplatePageResponse",
    "SalaryTemplateResponse",
    "SeverancePaymentPlanPageResponse",
    "SeverancePaymentPlanResponse",
    "SeverancePlanDetailItemRequest",
    "SeverancePlanDetailResponse",
    "SeverancePlanPageResponse",
    "SeverancePlanPaymentPlanItemRequest",
    "SeverancePlanRequest",
    "SeverancePlanResponse",
    "SeverancePlanResponseWithDetail",
    "ShiftPatternTemplateDetailItemRequest",
    "ShiftPatternTemplateDetailItemRequestShift",
    "ShiftPatternTemplateDetailResponse",
    "ShiftPatternTemplateItemResponse",
    "ShiftPatternTemplateListItemResponse",
    "ShiftPatternTemplatePageResponse",
    "ShiftPatternTemplateRequest",
    "ShiftPatternTemplateSimpleResponse",
    "ShiftResponse",
    "SortProperty",
    "StateListItemResponse",
    "StatePageResponse",
    "StateRequest",
    "StateResponse",
    "SubLocationLocationResponse",
    "SubLocationPageResponse",
    "SubLocationRequest",
    "SubLocationResponse",
    "TaxAmountResponse",
    "TaxAndAllowanceResponse",
    "TaxCalculationDetailResponse",
    "TaxCalculationIncomeRequest",
    "TaxCalculationPageResponse",
    "TaxCalculationRequest",
    "TaxCalculationResponse",
    "TaxDependentRequest",
    "TaxDependentResponse",
    "TaxIncomeResponse",
    "TaxMembershipHistoryResponse",
    "TaxMembershipPeriodResponse",
    "TaxMembershipResponse",
    "TaxMembershipTaxSubjectRequest",
    "TaxReport1721A1PageResponse",
    "TaxReport1721A1Response",
    "TaxReport1721VIDetailResponse",
    "TaxReport1721VIIIPageResponse",
    "TaxReport1721VIIIResponse",
    "TaxReport1721VIIPageResponse",
    "TaxReport1721VIIResponse",
    "TaxReport1721VIPageResponse",
    "TaxReport1721VIResponse",
    "TemporaryMonthlyTaxCalculationSimulatorResponse",
    "TerminationBPJSManpowerReasonPageResponse",
    "TerminationBPJSManpowerReasonResponse",
    "TerminationEntryRequest",
    "TerminationEntryResponse",
    "TerminationReasonCategoryPageResponse",
    "TerminationReasonCategoryResponse",
    "TerminationReasonDetailResponse",
    "TerminationReasonPageResponse",
    "TerminationReasonRequest",
    "TerminationReasonResponse",
    "TerminationTaxReasonPageResponse",
    "TerminationTaxReasonResponse",
    "TimeAllowanceDetailResponse",
    "TimeAllowanceDetailsResponse",
    "TimeZoneResponse",
    "TransitionCalculationCountResponse",
    "TransitionCalculationDetailsAmountRequest",
    "TransitionCalculationDetailsRequest",
    "TransitionCalculationEmployeeSalaryTemplateResponse",
    "TransitionCalculationResponse",
    "TransitionCalculationSalaryTemplateDetailResponse",
    "TransitionTimeAllowanceDetailResponse",
    "UnprocessableContentResponse",
    "UnprocessableMessage",
    "UnprocessedTransitionCalculationPageResponse",
    "UnprocessedTransitionCalculationResponse",
    "UpdateBankAccountConfigurationRequest",
    "UserAndRoleResponse",
    "UserPageResponse",
    "UserResponse",
    "WidgetContentResponse",
    "WidgetPageResponse",
    "WidgetResponse",
    "WorkdayConfigurationDetailResponse",
    "WorkflowActivityPageResponse",
    "WorkflowActivityResponse",
    "WorkflowReasonCategoryPageResponse",
    "WorkflowReasonCategoryRequest",
    "WorkflowReasonCategoryResponse",
    "WorkflowReasonPageResponse",
    "WorkflowReasonRequest",
    "WorkflowReasonResponse",
    "WorkflowTemplateResponse",
    "WorkgroupWorkdayConfigurationPageResponse",
    "WorkgroupWorkdayConfigurationRequest",
    "WorkgroupWorkdayConfigurationResponse",
]

# import apis into sdk package
from openapi_client.api.analytics_api import AnalyticsApi as AnalyticsApi
from openapi_client.api.anomaly_detection_api import AnomalyDetectionApi as AnomalyDetectionApi
from openapi_client.api.bank_account_configuration_api import BankAccountConfigurationApi as BankAccountConfigurationApi
from openapi_client.api.bpjs_healthcare_api import BpjsHealthcareApi as BpjsHealthcareApi
from openapi_client.api.bpjs_manpower_api import BpjsManpowerApi as BpjsManpowerApi
from openapi_client.api.company_bank_account_api import CompanyBankAccountApi as CompanyBankAccountApi
from openapi_client.api.contact_information_api import ContactInformationApi as ContactInformationApi
from openapi_client.api.custom_table_api import CustomTableApi as CustomTableApi
from openapi_client.api.custom_table_entry_api import CustomTableEntryApi as CustomTableEntryApi
from openapi_client.api.editable_salary_preprocess_api import EditableSalaryPreprocessApi as EditableSalaryPreprocessApi
from openapi_client.api.employee_api import EmployeeApi as EmployeeApi
from openapi_client.api.employee_bank_account_configuration_api import EmployeeBankAccountConfigurationApi as EmployeeBankAccountConfigurationApi
from openapi_client.api.employee_bpjs_membership_api import EmployeeBpjsMembershipApi as EmployeeBpjsMembershipApi
from openapi_client.api.employee_detail_api import EmployeeDetailApi as EmployeeDetailApi
from openapi_client.api.employee_paygroup_api import EmployeePaygroupApi as EmployeePaygroupApi
from openapi_client.api.employee_payment_item_group_sequence_api import EmployeePaymentItemGroupSequenceApi as EmployeePaymentItemGroupSequenceApi
from openapi_client.api.employee_salary_template_api import EmployeeSalaryTemplateApi as EmployeeSalaryTemplateApi
from openapi_client.api.employee_variable_api import EmployeeVariableApi as EmployeeVariableApi
from openapi_client.api.employment_status_api import EmploymentStatusApi as EmploymentStatusApi
from openapi_client.api.families_api import FamiliesApi as FamiliesApi
from openapi_client.api.former_employee_income_api import FormerEmployeeIncomeApi as FormerEmployeeIncomeApi
from openapi_client.api.identity_cards_api import IdentityCardsApi as IdentityCardsApi
from openapi_client.api.master_data_api import MasterDataApi as MasterDataApi
from openapi_client.api.oauth_client_api import OauthClientApi as OauthClientApi
from openapi_client.api.organization_api import OrganizationApi as OrganizationApi
from openapi_client.api.paygroup_api import PaygroupApi as PaygroupApi
from openapi_client.api.payroll_others_api import PayrollOthersApi as PayrollOthersApi
from openapi_client.api.payroll_process_snapshot_api import PayrollProcessSnapshotApi as PayrollProcessSnapshotApi
from openapi_client.api.payslip_api import PayslipApi as PayslipApi
from openapi_client.api.role_api import RoleApi as RoleApi
from openapi_client.api.salary_calculation_api import SalaryCalculationApi as SalaryCalculationApi
from openapi_client.api.salary_item_api import SalaryItemApi as SalaryItemApi
from openapi_client.api.salary_payment_api import SalaryPaymentApi as SalaryPaymentApi
from openapi_client.api.salary_template_api import SalaryTemplateApi as SalaryTemplateApi
from openapi_client.api.severance_api import SeveranceApi as SeveranceApi
from openapi_client.api.tax_api import TaxApi as TaxApi
from openapi_client.api.tax_membership_api import TaxMembershipApi as TaxMembershipApi
from openapi_client.api.tax_membership_history_api import TaxMembershipHistoryApi as TaxMembershipHistoryApi
from openapi_client.api.termination_api import TerminationApi as TerminationApi
from openapi_client.api.time_management_api import TimeManagementApi as TimeManagementApi
from openapi_client.api.transition_calculation_api import TransitionCalculationApi as TransitionCalculationApi
from openapi_client.api.user_api import UserApi as UserApi
from openapi_client.api.widgets_api import WidgetsApi as WidgetsApi
from openapi_client.api.workflow_api import WorkflowApi as WorkflowApi

# import ApiClient
from openapi_client.api_response import ApiResponse as ApiResponse
from openapi_client.api_client import ApiClient as ApiClient
from openapi_client.configuration import Configuration as Configuration
from openapi_client.exceptions import OpenApiException as OpenApiException
from openapi_client.exceptions import ApiTypeError as ApiTypeError
from openapi_client.exceptions import ApiValueError as ApiValueError
from openapi_client.exceptions import ApiKeyError as ApiKeyError
from openapi_client.exceptions import ApiAttributeError as ApiAttributeError
from openapi_client.exceptions import ApiException as ApiException

# import models into sdk package
from openapi_client.models.additional_assignment_approval_page_response import AdditionalAssignmentApprovalPageResponse as AdditionalAssignmentApprovalPageResponse
from openapi_client.models.additional_assignment_approval_response import AdditionalAssignmentApprovalResponse as AdditionalAssignmentApprovalResponse
from openapi_client.models.additional_assignment_approvale_sub_location_response import AdditionalAssignmentApprovaleSubLocationResponse as AdditionalAssignmentApprovaleSubLocationResponse
from openapi_client.models.additional_assignment_response import AdditionalAssignmentResponse as AdditionalAssignmentResponse
from openapi_client.models.additional_family_membership_response import AdditionalFamilyMembershipResponse as AdditionalFamilyMembershipResponse
from openapi_client.models.additional_income_payment_list_item_response import AdditionalIncomePaymentListItemResponse as AdditionalIncomePaymentListItemResponse
from openapi_client.models.additional_income_payment_page_response import AdditionalIncomePaymentPageResponse as AdditionalIncomePaymentPageResponse
from openapi_client.models.address_detail_response import AddressDetailResponse as AddressDetailResponse
from openapi_client.models.amount_request import AmountRequest as AmountRequest
from openapi_client.models.analytics_chart_data_response import AnalyticsChartDataResponse as AnalyticsChartDataResponse
from openapi_client.models.analytics_chart_data_series_response import AnalyticsChartDataSeriesResponse as AnalyticsChartDataSeriesResponse
from openapi_client.models.analytics_chart_page_response import AnalyticsChartPageResponse as AnalyticsChartPageResponse
from openapi_client.models.analytics_chart_request import AnalyticsChartRequest as AnalyticsChartRequest
from openapi_client.models.analytics_chart_response import AnalyticsChartResponse as AnalyticsChartResponse
from openapi_client.models.analytics_color_scheme_detail_response import AnalyticsColorSchemeDetailResponse as AnalyticsColorSchemeDetailResponse
from openapi_client.models.analytics_color_scheme_response import AnalyticsColorSchemeResponse as AnalyticsColorSchemeResponse
from openapi_client.models.analytics_column_response import AnalyticsColumnResponse as AnalyticsColumnResponse
from openapi_client.models.annual_tax_calculation_simulator_monthly_tax_reports_response import AnnualTaxCalculationSimulatorMonthlyTaxReportsResponse as AnnualTaxCalculationSimulatorMonthlyTaxReportsResponse
from openapi_client.models.annual_tax_calculation_simulator_request import AnnualTaxCalculationSimulatorRequest as AnnualTaxCalculationSimulatorRequest
from openapi_client.models.annual_tax_calculation_simulator_response import AnnualTaxCalculationSimulatorResponse as AnnualTaxCalculationSimulatorResponse
from openapi_client.models.annual_tax_calculation_simulator_result_response import AnnualTaxCalculationSimulatorResultResponse as AnnualTaxCalculationSimulatorResultResponse
from openapi_client.models.anomaly_suspect_attribute_response import AnomalySuspectAttributeResponse as AnomalySuspectAttributeResponse
from openapi_client.models.anomaly_suspect_attribute_value_child_response import AnomalySuspectAttributeValueChildResponse as AnomalySuspectAttributeValueChildResponse
from openapi_client.models.anomaly_suspect_attribute_value_response import AnomalySuspectAttributeValueResponse as AnomalySuspectAttributeValueResponse
from openapi_client.models.anomaly_suspect_file_response import AnomalySuspectFileResponse as AnomalySuspectFileResponse
from openapi_client.models.anomaly_suspect_page_response import AnomalySuspectPageResponse as AnomalySuspectPageResponse
from openapi_client.models.anomaly_suspect_response import AnomalySuspectResponse as AnomalySuspectResponse
from openapi_client.models.attendance_item_response import AttendanceItemResponse as AttendanceItemResponse
from openapi_client.models.attendance_page_response import AttendancePageResponse as AttendancePageResponse
from openapi_client.models.attendance_recapitulation_detail_attendance_item_response import AttendanceRecapitulationDetailAttendanceItemResponse as AttendanceRecapitulationDetailAttendanceItemResponse
from openapi_client.models.attendance_recapitulation_detail_item_response import AttendanceRecapitulationDetailItemResponse as AttendanceRecapitulationDetailItemResponse
from openapi_client.models.attendance_recapitulation_detail_overtime_response import AttendanceRecapitulationDetailOvertimeResponse as AttendanceRecapitulationDetailOvertimeResponse
from openapi_client.models.attendance_recapitulation_detail_page_response import AttendanceRecapitulationDetailPageResponse as AttendanceRecapitulationDetailPageResponse
from openapi_client.models.attendance_status_response import AttendanceStatusResponse as AttendanceStatusResponse
from openapi_client.models.authority_detail_response import AuthorityDetailResponse as AuthorityDetailResponse
from openapi_client.models.bank_account_configuration_page_response import BankAccountConfigurationPageResponse as BankAccountConfigurationPageResponse
from openapi_client.models.bank_account_configuration_request import BankAccountConfigurationRequest as BankAccountConfigurationRequest
from openapi_client.models.bank_account_configuration_response import BankAccountConfigurationResponse as BankAccountConfigurationResponse
from openapi_client.models.bank_account_configuration_response_source import BankAccountConfigurationResponseSource as BankAccountConfigurationResponseSource
from openapi_client.models.bank_account_response import BankAccountResponse as BankAccountResponse
from openapi_client.models.bank_branch_page_response import BankBranchPageResponse as BankBranchPageResponse
from openapi_client.models.bank_branch_response import BankBranchResponse as BankBranchResponse
from openapi_client.models.bank_branch_simple_response import BankBranchSimpleResponse as BankBranchSimpleResponse
from openapi_client.models.bank_page_response import BankPageResponse as BankPageResponse
from openapi_client.models.bank_response import BankResponse as BankResponse
from openapi_client.models.bpjs_healthcare_current_month_detail_response import BpjsHealthcareCurrentMonthDetailResponse as BpjsHealthcareCurrentMonthDetailResponse
from openapi_client.models.bpjs_healthcare_membership_additional_family_membership import BpjsHealthcareMembershipAdditionalFamilyMembership as BpjsHealthcareMembershipAdditionalFamilyMembership
from openapi_client.models.bpjs_healthcare_membership_request import BpjsHealthcareMembershipRequest as BpjsHealthcareMembershipRequest
from openapi_client.models.bpjs_healthcare_membership_response import BpjsHealthcareMembershipResponse as BpjsHealthcareMembershipResponse
from openapi_client.models.bpjs_healthcare_premium_details_item_response import BpjsHealthcarePremiumDetailsItemResponse as BpjsHealthcarePremiumDetailsItemResponse
from openapi_client.models.bpjs_healthcare_premium_details_response import BpjsHealthcarePremiumDetailsResponse as BpjsHealthcarePremiumDetailsResponse
from openapi_client.models.bpjs_healthcare_premium_summary_list_item_response import BpjsHealthcarePremiumSummaryListItemResponse as BpjsHealthcarePremiumSummaryListItemResponse
from openapi_client.models.bpjs_healthcare_premium_summary_page_response import BpjsHealthcarePremiumSummaryPageResponse as BpjsHealthcarePremiumSummaryPageResponse
from openapi_client.models.bpjs_healthcare_provider_list_item_response import BpjsHealthcareProviderListItemResponse as BpjsHealthcareProviderListItemResponse
from openapi_client.models.bpjs_healthcare_provider_page_response import BpjsHealthcareProviderPageResponse as BpjsHealthcareProviderPageResponse
from openapi_client.models.bpjs_healthcare_template_list_item_response import BpjsHealthcareTemplateListItemResponse as BpjsHealthcareTemplateListItemResponse
from openapi_client.models.bpjs_healthcare_template_page_response import BpjsHealthcareTemplatePageResponse as BpjsHealthcareTemplatePageResponse
from openapi_client.models.bpjs_healthcare_treatment_class_response import BpjsHealthcareTreatmentClassResponse as BpjsHealthcareTreatmentClassResponse
from openapi_client.models.bpjs_manpower_current_month_detail_response import BpjsManpowerCurrentMonthDetailResponse as BpjsManpowerCurrentMonthDetailResponse
from openapi_client.models.bpjs_manpower_membership_request import BpjsManpowerMembershipRequest as BpjsManpowerMembershipRequest
from openapi_client.models.bpjs_manpower_membership_response import BpjsManpowerMembershipResponse as BpjsManpowerMembershipResponse
from openapi_client.models.bpjs_manpower_premium_details_item_response import BpjsManpowerPremiumDetailsItemResponse as BpjsManpowerPremiumDetailsItemResponse
from openapi_client.models.bpjs_manpower_premium_details_response import BpjsManpowerPremiumDetailsResponse as BpjsManpowerPremiumDetailsResponse
from openapi_client.models.bpjs_manpower_premium_summary_list_item_response import BpjsManpowerPremiumSummaryListItemResponse as BpjsManpowerPremiumSummaryListItemResponse
from openapi_client.models.bpjs_manpower_premium_summary_page_response import BpjsManpowerPremiumSummaryPageResponse as BpjsManpowerPremiumSummaryPageResponse
from openapi_client.models.bpjs_manpower_provider_page_response import BpjsManpowerProviderPageResponse as BpjsManpowerProviderPageResponse
from openapi_client.models.bpjs_manpower_provider_response import BpjsManpowerProviderResponse as BpjsManpowerProviderResponse
from openapi_client.models.bpjs_manpower_template_page_response import BpjsManpowerTemplatePageResponse as BpjsManpowerTemplatePageResponse
from openapi_client.models.bpjs_manpower_template_response import BpjsManpowerTemplateResponse as BpjsManpowerTemplateResponse
from openapi_client.models.bulk_operation_failure_param_response import BulkOperationFailureParamResponse as BulkOperationFailureParamResponse
from openapi_client.models.bulk_operation_failure_response import BulkOperationFailureResponse as BulkOperationFailureResponse
from openapi_client.models.bulk_operation_response import BulkOperationResponse as BulkOperationResponse
from openapi_client.models.calculation_scenario_component import CalculationScenarioComponent as CalculationScenarioComponent
from openapi_client.models.calculation_scenario_previous_job_component import CalculationScenarioPreviousJobComponent as CalculationScenarioPreviousJobComponent
from openapi_client.models.calculation_scenario_salary_component import CalculationScenarioSalaryComponent as CalculationScenarioSalaryComponent
from openapi_client.models.chart_filter_request import ChartFilterRequest as ChartFilterRequest
from openapi_client.models.chart_filter_response import ChartFilterResponse as ChartFilterResponse
from openapi_client.models.chart_table_relation_request import ChartTableRelationRequest as ChartTableRelationRequest
from openapi_client.models.chart_table_relation_response import ChartTableRelationResponse as ChartTableRelationResponse
from openapi_client.models.chart_value_collection_filter_request import ChartValueCollectionFilterRequest as ChartValueCollectionFilterRequest
from openapi_client.models.city_page_response import CityPageResponse as CityPageResponse
from openapi_client.models.city_response import CityResponse as CityResponse
from openapi_client.models.company_bank_account_page_response import CompanyBankAccountPageResponse as CompanyBankAccountPageResponse
from openapi_client.models.company_bank_account_response import CompanyBankAccountResponse as CompanyBankAccountResponse
from openapi_client.models.company_detail_request import CompanyDetailRequest as CompanyDetailRequest
from openapi_client.models.company_detail_response import CompanyDetailResponse as CompanyDetailResponse
from openapi_client.models.company_detail_time_zone_request import CompanyDetailTimeZoneRequest as CompanyDetailTimeZoneRequest
from openapi_client.models.company_group_page_response import CompanyGroupPageResponse as CompanyGroupPageResponse
from openapi_client.models.company_list_item_response import CompanyListItemResponse as CompanyListItemResponse
from openapi_client.models.company_page_response import CompanyPageResponse as CompanyPageResponse
from openapi_client.models.company_superior_response import CompanySuperiorResponse as CompanySuperiorResponse
from openapi_client.models.contact_information_page_response import ContactInformationPageResponse as ContactInformationPageResponse
from openapi_client.models.contact_information_request import ContactInformationRequest as ContactInformationRequest
from openapi_client.models.contact_information_response import ContactInformationResponse as ContactInformationResponse
from openapi_client.models.cost_center_list_item_response import CostCenterListItemResponse as CostCenterListItemResponse
from openapi_client.models.cost_center_page_response import CostCenterPageResponse as CostCenterPageResponse
from openapi_client.models.cost_center_request import CostCenterRequest as CostCenterRequest
from openapi_client.models.cost_center_response import CostCenterResponse as CostCenterResponse
from openapi_client.models.cost_center_simple_response import CostCenterSimpleResponse as CostCenterSimpleResponse
from openapi_client.models.count_response import CountResponse as CountResponse
from openapi_client.models.country_page_response import CountryPageResponse as CountryPageResponse
from openapi_client.models.country_request import CountryRequest as CountryRequest
from openapi_client.models.country_response import CountryResponse as CountryResponse
from openapi_client.models.create_city_request import CreateCityRequest as CreateCityRequest
from openapi_client.models.create_city_request_state import CreateCityRequestState as CreateCityRequestState
from openapi_client.models.currency_page_response import CurrencyPageResponse as CurrencyPageResponse
from openapi_client.models.currency_response import CurrencyResponse as CurrencyResponse
from openapi_client.models.currency_simple_response import CurrencySimpleResponse as CurrencySimpleResponse
from openapi_client.models.custom_table_column_response import CustomTableColumnResponse as CustomTableColumnResponse
from openapi_client.models.custom_table_entry_page_response import CustomTableEntryPageResponse as CustomTableEntryPageResponse
from openapi_client.models.custom_table_page_response import CustomTablePageResponse as CustomTablePageResponse
from openapi_client.models.custom_table_response import CustomTableResponse as CustomTableResponse
from openapi_client.models.editable_salary_preprocess_request import EditableSalaryPreprocessRequest as EditableSalaryPreprocessRequest
from openapi_client.models.editable_salary_preprocess_response import EditableSalaryPreprocessResponse as EditableSalaryPreprocessResponse
from openapi_client.models.editable_salary_preprocess_success import EditableSalaryPreprocessSuccess as EditableSalaryPreprocessSuccess
from openapi_client.models.education_level_page_response import EducationLevelPageResponse as EducationLevelPageResponse
from openapi_client.models.education_level_response import EducationLevelResponse as EducationLevelResponse
from openapi_client.models.education_page_response import EducationPageResponse as EducationPageResponse
from openapi_client.models.education_response import EducationResponse as EducationResponse
from openapi_client.models.emergency_contact_response import EmergencyContactResponse as EmergencyContactResponse
from openapi_client.models.employee_create_response import EmployeeCreateResponse as EmployeeCreateResponse
from openapi_client.models.employee_detail_page_response import EmployeeDetailPageResponse as EmployeeDetailPageResponse
from openapi_client.models.employee_detail_request import EmployeeDetailRequest as EmployeeDetailRequest
from openapi_client.models.employee_detail_response import EmployeeDetailResponse as EmployeeDetailResponse
from openapi_client.models.employee_full_response import EmployeeFullResponse as EmployeeFullResponse
from openapi_client.models.employee_hiring_data_request import EmployeeHiringDataRequest as EmployeeHiringDataRequest
from openapi_client.models.employee_hiring_data_response import EmployeeHiringDataResponse as EmployeeHiringDataResponse
from openapi_client.models.employee_hiring_data_simple_response import EmployeeHiringDataSimpleResponse as EmployeeHiringDataSimpleResponse
from openapi_client.models.employee_id_identification_number_response import EmployeeIdIdentificationNumberResponse as EmployeeIdIdentificationNumberResponse
from openapi_client.models.employee_id_name_response import EmployeeIdNameResponse as EmployeeIdNameResponse
from openapi_client.models.employee_identification_number_response import EmployeeIdentificationNumberResponse as EmployeeIdentificationNumberResponse
from openapi_client.models.employee_identity_card_page_response import EmployeeIdentityCardPageResponse as EmployeeIdentityCardPageResponse
from openapi_client.models.employee_identity_card_request import EmployeeIdentityCardRequest as EmployeeIdentityCardRequest
from openapi_client.models.employee_identity_card_response import EmployeeIdentityCardResponse as EmployeeIdentityCardResponse
from openapi_client.models.employee_manager_response import EmployeeManagerResponse as EmployeeManagerResponse
from openapi_client.models.employee_page_response import EmployeePageResponse as EmployeePageResponse
from openapi_client.models.employee_paygroup_page_response import EmployeePaygroupPageResponse as EmployeePaygroupPageResponse
from openapi_client.models.employee_paygroup_response import EmployeePaygroupResponse as EmployeePaygroupResponse
from openapi_client.models.employee_request import EmployeeRequest as EmployeeRequest
from openapi_client.models.employee_response import EmployeeResponse as EmployeeResponse
from openapi_client.models.employee_salary_request import EmployeeSalaryRequest as EmployeeSalaryRequest
from openapi_client.models.employee_salary_response import EmployeeSalaryResponse as EmployeeSalaryResponse
from openapi_client.models.employee_salary_template_page_response import EmployeeSalaryTemplatePageResponse as EmployeeSalaryTemplatePageResponse
from openapi_client.models.employee_salary_template_request import EmployeeSalaryTemplateRequest as EmployeeSalaryTemplateRequest
from openapi_client.models.employee_salary_template_response import EmployeeSalaryTemplateResponse as EmployeeSalaryTemplateResponse
from openapi_client.models.employee_salary_template_update_response import EmployeeSalaryTemplateUpdateResponse as EmployeeSalaryTemplateUpdateResponse
from openapi_client.models.employee_simple_response import EmployeeSimpleResponse as EmployeeSimpleResponse
from openapi_client.models.employee_variable_metadata_page_response import EmployeeVariableMetadataPageResponse as EmployeeVariableMetadataPageResponse
from openapi_client.models.employee_variable_metadata_request import EmployeeVariableMetadataRequest as EmployeeVariableMetadataRequest
from openapi_client.models.employee_variable_metadata_response import EmployeeVariableMetadataResponse as EmployeeVariableMetadataResponse
from openapi_client.models.employee_variable_page_response import EmployeeVariablePageResponse as EmployeeVariablePageResponse
from openapi_client.models.employee_variable_request import EmployeeVariableRequest as EmployeeVariableRequest
from openapi_client.models.employee_variable_response import EmployeeVariableResponse as EmployeeVariableResponse
from openapi_client.models.employee_variable_validation_request import EmployeeVariableValidationRequest as EmployeeVariableValidationRequest
from openapi_client.models.employee_variable_validation_response import EmployeeVariableValidationResponse as EmployeeVariableValidationResponse
from openapi_client.models.employee_workday_configuration_page_response import EmployeeWorkdayConfigurationPageResponse as EmployeeWorkdayConfigurationPageResponse
from openapi_client.models.employee_workday_configuration_request import EmployeeWorkdayConfigurationRequest as EmployeeWorkdayConfigurationRequest
from openapi_client.models.employee_workday_configuration_response import EmployeeWorkdayConfigurationResponse as EmployeeWorkdayConfigurationResponse
from openapi_client.models.employment_data_position_response import EmploymentDataPositionResponse as EmploymentDataPositionResponse
from openapi_client.models.employment_data_request import EmploymentDataRequest as EmploymentDataRequest
from openapi_client.models.employment_data_response import EmploymentDataResponse as EmploymentDataResponse
from openapi_client.models.employment_status_detail_position_response import EmploymentStatusDetailPositionResponse as EmploymentStatusDetailPositionResponse
from openapi_client.models.employment_status_detail_response import EmploymentStatusDetailResponse as EmploymentStatusDetailResponse
from openapi_client.models.employment_status_history_detail_response import EmploymentStatusHistoryDetailResponse as EmploymentStatusHistoryDetailResponse
from openapi_client.models.employment_status_history_page_response import EmploymentStatusHistoryPageResponse as EmploymentStatusHistoryPageResponse
from openapi_client.models.employment_status_page_response import EmploymentStatusPageResponse as EmploymentStatusPageResponse
from openapi_client.models.employment_status_type_page_response import EmploymentStatusTypePageResponse as EmploymentStatusTypePageResponse
from openapi_client.models.employment_status_type_response import EmploymentStatusTypeResponse as EmploymentStatusTypeResponse
from openapi_client.models.employment_type_page_response import EmploymentTypePageResponse as EmploymentTypePageResponse
from openapi_client.models.employment_type_request import EmploymentTypeRequest as EmploymentTypeRequest
from openapi_client.models.employment_type_response import EmploymentTypeResponse as EmploymentTypeResponse
from openapi_client.models.error_response import ErrorResponse as ErrorResponse
from openapi_client.models.family_approval_list_item_response import FamilyApprovalListItemResponse as FamilyApprovalListItemResponse
from openapi_client.models.family_approval_list_item_with_approval_status_response import FamilyApprovalListItemWithApprovalStatusResponse as FamilyApprovalListItemWithApprovalStatusResponse
from openapi_client.models.family_approval_page_response import FamilyApprovalPageResponse as FamilyApprovalPageResponse
from openapi_client.models.family_approval_request import FamilyApprovalRequest as FamilyApprovalRequest
from openapi_client.models.family_approval_response import FamilyApprovalResponse as FamilyApprovalResponse
from openapi_client.models.family_historical_page_response import FamilyHistoricalPageResponse as FamilyHistoricalPageResponse
from openapi_client.models.family_historical_response import FamilyHistoricalResponse as FamilyHistoricalResponse
from openapi_client.models.family_member_relation_page_response import FamilyMemberRelationPageResponse as FamilyMemberRelationPageResponse
from openapi_client.models.family_member_relation_response import FamilyMemberRelationResponse as FamilyMemberRelationResponse
from openapi_client.models.field_of_study_page_response import FieldOfStudyPageResponse as FieldOfStudyPageResponse
from openapi_client.models.field_of_study_response import FieldOfStudyResponse as FieldOfStudyResponse
from openapi_client.models.fingerprint_failure_item_response import FingerprintFailureItemResponse as FingerprintFailureItemResponse
from openapi_client.models.fingerprint_item_request import FingerprintItemRequest as FingerprintItemRequest
from openapi_client.models.fingerprint_response import FingerprintResponse as FingerprintResponse
from openapi_client.models.fingerprint_success_item_response import FingerprintSuccessItemResponse as FingerprintSuccessItemResponse
from openapi_client.models.former_employee_income_employee_amount_update_request import FormerEmployeeIncomeEmployeeAmountUpdateRequest as FormerEmployeeIncomeEmployeeAmountUpdateRequest
from openapi_client.models.former_employee_income_employee_page_response import FormerEmployeeIncomeEmployeePageResponse as FormerEmployeeIncomeEmployeePageResponse
from openapi_client.models.former_employee_income_employee_response import FormerEmployeeIncomeEmployeeResponse as FormerEmployeeIncomeEmployeeResponse
from openapi_client.models.former_employee_income_page_response import FormerEmployeeIncomePageResponse as FormerEmployeeIncomePageResponse
from openapi_client.models.former_employee_income_response import FormerEmployeeIncomeResponse as FormerEmployeeIncomeResponse
from openapi_client.models.holiday_item_response import HolidayItemResponse as HolidayItemResponse
from openapi_client.models.holiday_page_response import HolidayPageResponse as HolidayPageResponse
from openapi_client.models.id_code_name_response import IdCodeNameResponse as IdCodeNameResponse
from openapi_client.models.id_request import IdRequest as IdRequest
from openapi_client.models.id_response import IdResponse as IdResponse
from openapi_client.models.identity_card_page_response import IdentityCardPageResponse as IdentityCardPageResponse
from openapi_client.models.identity_card_response import IdentityCardResponse as IdentityCardResponse
from openapi_client.models.institution_page_response import InstitutionPageResponse as InstitutionPageResponse
from openapi_client.models.institution_response import InstitutionResponse as InstitutionResponse
from openapi_client.models.job_level_page_response import JobLevelPageResponse as JobLevelPageResponse
from openapi_client.models.job_level_request import JobLevelRequest as JobLevelRequest
from openapi_client.models.job_level_response import JobLevelResponse as JobLevelResponse
from openapi_client.models.job_title_level_mapping_page_response import JobTitleLevelMappingPageResponse as JobTitleLevelMappingPageResponse
from openapi_client.models.job_title_level_mapping_response import JobTitleLevelMappingResponse as JobTitleLevelMappingResponse
from openapi_client.models.job_title_page_response import JobTitlePageResponse as JobTitlePageResponse
from openapi_client.models.job_title_request import JobTitleRequest as JobTitleRequest
from openapi_client.models.job_title_request_deprecated import JobTitleRequestDeprecated as JobTitleRequestDeprecated
from openapi_client.models.job_title_response import JobTitleResponse as JobTitleResponse
from openapi_client.models.job_title_with_job_levels_response import JobTitleWithJobLevelsResponse as JobTitleWithJobLevelsResponse
from openapi_client.models.kpp_page_response import KppPageResponse as KppPageResponse
from openapi_client.models.kpp_response import KppResponse as KppResponse
from openapi_client.models.kpp_simple_response import KppSimpleResponse as KppSimpleResponse
from openapi_client.models.leave_balance_item_response import LeaveBalanceItemResponse as LeaveBalanceItemResponse
from openapi_client.models.leave_balance_page_response import LeaveBalancePageResponse as LeaveBalancePageResponse
from openapi_client.models.leave_balance_request import LeaveBalanceRequest as LeaveBalanceRequest
from openapi_client.models.location_create_request import LocationCreateRequest as LocationCreateRequest
from openapi_client.models.location_group_page_response import LocationGroupPageResponse as LocationGroupPageResponse
from openapi_client.models.location_page_response import LocationPageResponse as LocationPageResponse
from openapi_client.models.location_response import LocationResponse as LocationResponse
from openapi_client.models.logo_file_metadata_response import LogoFileMetadataResponse as LogoFileMetadataResponse
from openapi_client.models.manager_request import ManagerRequest as ManagerRequest
from openapi_client.models.monthly_recapitulation_item_detail_response import MonthlyRecapitulationItemDetailResponse as MonthlyRecapitulationItemDetailResponse
from openapi_client.models.monthly_recapitulation_item_response import MonthlyRecapitulationItemResponse as MonthlyRecapitulationItemResponse
from openapi_client.models.monthly_recapitulation_page_response import MonthlyRecapitulationPageResponse as MonthlyRecapitulationPageResponse
from openapi_client.models.monthly_tax_calculation_simulator_request import MonthlyTaxCalculationSimulatorRequest as MonthlyTaxCalculationSimulatorRequest
from openapi_client.models.monthly_tax_calculation_simulator_response import MonthlyTaxCalculationSimulatorResponse as MonthlyTaxCalculationSimulatorResponse
from openapi_client.models.monthly_tax_detail_page_response import MonthlyTaxDetailPageResponse as MonthlyTaxDetailPageResponse
from openapi_client.models.monthly_tax_detail_response import MonthlyTaxDetailResponse as MonthlyTaxDetailResponse
from openapi_client.models.monthly_tax_report_page_response import MonthlyTaxReportPageResponse as MonthlyTaxReportPageResponse
from openapi_client.models.monthly_tax_report_response import MonthlyTaxReportResponse as MonthlyTaxReportResponse
from openapi_client.models.name_response import NameResponse as NameResponse
from openapi_client.models.non_employee_monthly_tax_calculation_simulator_response import NonEmployeeMonthlyTaxCalculationSimulatorResponse as NonEmployeeMonthlyTaxCalculationSimulatorResponse
from openapi_client.models.o_auth_client_page_response import OAuthClientPageResponse as OAuthClientPageResponse
from openapi_client.models.o_auth_client_response import OAuthClientResponse as OAuthClientResponse
from openapi_client.models.operational_group_page_response import OperationalGroupPageResponse as OperationalGroupPageResponse
from openapi_client.models.organization_group_page_response import OrganizationGroupPageResponse as OrganizationGroupPageResponse
from openapi_client.models.organization_group_request import OrganizationGroupRequest as OrganizationGroupRequest
from openapi_client.models.organization_head_page_response import OrganizationHeadPageResponse as OrganizationHeadPageResponse
from openapi_client.models.organization_head_response import OrganizationHeadResponse as OrganizationHeadResponse
from openapi_client.models.organization_hierarchy_page_response import OrganizationHierarchyPageResponse as OrganizationHierarchyPageResponse
from openapi_client.models.organization_hierarchy_request import OrganizationHierarchyRequest as OrganizationHierarchyRequest
from openapi_client.models.organization_hierarchy_response import OrganizationHierarchyResponse as OrganizationHierarchyResponse
from openapi_client.models.organization_history_hierarchy_response import OrganizationHistoryHierarchyResponse as OrganizationHistoryHierarchyResponse
from openapi_client.models.organization_history_page_response import OrganizationHistoryPageResponse as OrganizationHistoryPageResponse
from openapi_client.models.organization_history_response import OrganizationHistoryResponse as OrganizationHistoryResponse
from openapi_client.models.organization_page_response import OrganizationPageResponse as OrganizationPageResponse
from openapi_client.models.organization_parent_response import OrganizationParentResponse as OrganizationParentResponse
from openapi_client.models.organization_request import OrganizationRequest as OrganizationRequest
from openapi_client.models.organization_response import OrganizationResponse as OrganizationResponse
from openapi_client.models.organization_superior_page_response import OrganizationSuperiorPageResponse as OrganizationSuperiorPageResponse
from openapi_client.models.organization_superior_response import OrganizationSuperiorResponse as OrganizationSuperiorResponse
from openapi_client.models.other_leave_balance_create_response import OtherLeaveBalanceCreateResponse as OtherLeaveBalanceCreateResponse
from openapi_client.models.other_leave_balance_item_response import OtherLeaveBalanceItemResponse as OtherLeaveBalanceItemResponse
from openapi_client.models.other_leave_balance_page_response import OtherLeaveBalancePageResponse as OtherLeaveBalancePageResponse
from openapi_client.models.other_leave_balance_request import OtherLeaveBalanceRequest as OtherLeaveBalanceRequest
from openapi_client.models.other_leave_status_response import OtherLeaveStatusResponse as OtherLeaveStatusResponse
from openapi_client.models.page import Page as Page
from openapi_client.models.paygroup_page_response import PaygroupPageResponse as PaygroupPageResponse
from openapi_client.models.paygroup_response import PaygroupResponse as PaygroupResponse
from openapi_client.models.payment_item_detail_response import PaymentItemDetailResponse as PaymentItemDetailResponse
from openapi_client.models.payment_item_detail_salary_item_response import PaymentItemDetailSalaryItemResponse as PaymentItemDetailSalaryItemResponse
from openapi_client.models.payment_item_group_last_sequence_response import PaymentItemGroupLastSequenceResponse as PaymentItemGroupLastSequenceResponse
from openapi_client.models.payment_item_group_page_response import PaymentItemGroupPageResponse as PaymentItemGroupPageResponse
from openapi_client.models.payment_item_group_response import PaymentItemGroupResponse as PaymentItemGroupResponse
from openapi_client.models.payment_item_group_sequence_response import PaymentItemGroupSequenceResponse as PaymentItemGroupSequenceResponse
from openapi_client.models.payroll_process_snapshot_bank_account_configuration_response import PayrollProcessSnapshotBankAccountConfigurationResponse as PayrollProcessSnapshotBankAccountConfigurationResponse
from openapi_client.models.payroll_process_snapshot_bank_account_response import PayrollProcessSnapshotBankAccountResponse as PayrollProcessSnapshotBankAccountResponse
from openapi_client.models.payroll_process_snapshot_employment_status_response import PayrollProcessSnapshotEmploymentStatusResponse as PayrollProcessSnapshotEmploymentStatusResponse
from openapi_client.models.payroll_process_snapshot_page_response import PayrollProcessSnapshotPageResponse as PayrollProcessSnapshotPageResponse
from openapi_client.models.payroll_process_snapshot_response import PayrollProcessSnapshotResponse as PayrollProcessSnapshotResponse
from openapi_client.models.payroll_process_snapshot_workflow_activity_response import PayrollProcessSnapshotWorkflowActivityResponse as PayrollProcessSnapshotWorkflowActivityResponse
from openapi_client.models.payroll_process_snapshot_workflow_reason_response import PayrollProcessSnapshotWorkflowReasonResponse as PayrollProcessSnapshotWorkflowReasonResponse
from openapi_client.models.payroll_process_snapshot_workflow_template_response import PayrollProcessSnapshotWorkflowTemplateResponse as PayrollProcessSnapshotWorkflowTemplateResponse
from openapi_client.models.payslip_additional_note_page_response import PayslipAdditionalNotePageResponse as PayslipAdditionalNotePageResponse
from openapi_client.models.payslip_additional_note_request import PayslipAdditionalNoteRequest as PayslipAdditionalNoteRequest
from openapi_client.models.payslip_additional_note_response import PayslipAdditionalNoteResponse as PayslipAdditionalNoteResponse
from openapi_client.models.payslip_download_request import PayslipDownloadRequest as PayslipDownloadRequest
from openapi_client.models.payslip_layout_page_response import PayslipLayoutPageResponse as PayslipLayoutPageResponse
from openapi_client.models.payslip_layout_request import PayslipLayoutRequest as PayslipLayoutRequest
from openapi_client.models.payslip_layout_response import PayslipLayoutResponse as PayslipLayoutResponse
from openapi_client.models.permanent_monthly_tax_calculation_simulator_response import PermanentMonthlyTaxCalculationSimulatorResponse as PermanentMonthlyTaxCalculationSimulatorResponse
from openapi_client.models.photo_response import PhotoResponse as PhotoResponse
from openapi_client.models.place_of_birth_request import PlaceOfBirthRequest as PlaceOfBirthRequest
from openapi_client.models.place_of_birth_response import PlaceOfBirthResponse as PlaceOfBirthResponse
from openapi_client.models.point_of_hire_response import PointOfHireResponse as PointOfHireResponse
from openapi_client.models.position_cost_center_page_response import PositionCostCenterPageResponse as PositionCostCenterPageResponse
from openapi_client.models.position_cost_center_response import PositionCostCenterResponse as PositionCostCenterResponse
from openapi_client.models.position_history_organization_response import PositionHistoryOrganizationResponse as PositionHistoryOrganizationResponse
from openapi_client.models.position_history_page_response import PositionHistoryPageResponse as PositionHistoryPageResponse
from openapi_client.models.position_history_response import PositionHistoryResponse as PositionHistoryResponse
from openapi_client.models.position_list_item_response import PositionListItemResponse as PositionListItemResponse
from openapi_client.models.position_page_response import PositionPageResponse as PositionPageResponse
from openapi_client.models.position_response import PositionResponse as PositionResponse
from openapi_client.models.position_vacancy_status_page_response import PositionVacancyStatusPageResponse as PositionVacancyStatusPageResponse
from openapi_client.models.position_vacancy_status_response import PositionVacancyStatusResponse as PositionVacancyStatusResponse
from openapi_client.models.pph21_policy_response import Pph21PolicyResponse as Pph21PolicyResponse
from openapi_client.models.processable_time_allowance_transition_employee_response import ProcessableTimeAllowanceTransitionEmployeeResponse as ProcessableTimeAllowanceTransitionEmployeeResponse
from openapi_client.models.processable_time_allowance_transition_employment_status_response import ProcessableTimeAllowanceTransitionEmploymentStatusResponse as ProcessableTimeAllowanceTransitionEmploymentStatusResponse
from openapi_client.models.processable_time_allowance_transition_page_response import ProcessableTimeAllowanceTransitionPageResponse as ProcessableTimeAllowanceTransitionPageResponse
from openapi_client.models.processable_time_allowance_transition_response import ProcessableTimeAllowanceTransitionResponse as ProcessableTimeAllowanceTransitionResponse
from openapi_client.models.processed_salary_payment_detail_response import ProcessedSalaryPaymentDetailResponse as ProcessedSalaryPaymentDetailResponse
from openapi_client.models.processed_salary_payment_page_response import ProcessedSalaryPaymentPageResponse as ProcessedSalaryPaymentPageResponse
from openapi_client.models.processed_salary_payment_response import ProcessedSalaryPaymentResponse as ProcessedSalaryPaymentResponse
from openapi_client.models.processed_transition_calculation_page_response import ProcessedTransitionCalculationPageResponse as ProcessedTransitionCalculationPageResponse
from openapi_client.models.processed_transition_calculation_response import ProcessedTransitionCalculationResponse as ProcessedTransitionCalculationResponse
from openapi_client.models.prorate_detail_response import ProrateDetailResponse as ProrateDetailResponse
from openapi_client.models.prorate_detail_salary_template_detail_response import ProrateDetailSalaryTemplateDetailResponse as ProrateDetailSalaryTemplateDetailResponse
from openapi_client.models.prorate_detail_salary_template_detail_salary_item_response import ProrateDetailSalaryTemplateDetailSalaryItemResponse as ProrateDetailSalaryTemplateDetailSalaryItemResponse
from openapi_client.models.ptkp_category_page_response import PtkpCategoryPageResponse as PtkpCategoryPageResponse
from openapi_client.models.ptkp_category_response import PtkpCategoryResponse as PtkpCategoryResponse
from openapi_client.models.recurring_configuration_request import RecurringConfigurationRequest as RecurringConfigurationRequest
from openapi_client.models.recurring_configuration_response import RecurringConfigurationResponse as RecurringConfigurationResponse
from openapi_client.models.recurring_period_end_request import RecurringPeriodEndRequest as RecurringPeriodEndRequest
from openapi_client.models.recurring_period_end_response import RecurringPeriodEndResponse as RecurringPeriodEndResponse
from openapi_client.models.reject_approval_request import RejectApprovalRequest as RejectApprovalRequest
from openapi_client.models.religion_page_response import ReligionPageResponse as ReligionPageResponse
from openapi_client.models.religion_request import ReligionRequest as ReligionRequest
from openapi_client.models.religion_response import ReligionResponse as ReligionResponse
from openapi_client.models.role_authority_page_response import RoleAuthorityPageResponse as RoleAuthorityPageResponse
from openapi_client.models.role_authority_response import RoleAuthorityResponse as RoleAuthorityResponse
from openapi_client.models.role_detail_response import RoleDetailResponse as RoleDetailResponse
from openapi_client.models.role_id_name_response import RoleIdNameResponse as RoleIdNameResponse
from openapi_client.models.role_page_response import RolePageResponse as RolePageResponse
from openapi_client.models.role_permission_page_response import RolePermissionPageResponse as RolePermissionPageResponse
from openapi_client.models.role_permission_response import RolePermissionResponse as RolePermissionResponse
from openapi_client.models.role_response import RoleResponse as RoleResponse
from openapi_client.models.salary_calculation_detail_page_response import SalaryCalculationDetailPageResponse as SalaryCalculationDetailPageResponse
from openapi_client.models.salary_calculation_detail_response import SalaryCalculationDetailResponse as SalaryCalculationDetailResponse
from openapi_client.models.salary_calculation_page_response import SalaryCalculationPageResponse as SalaryCalculationPageResponse
from openapi_client.models.salary_calculation_response import SalaryCalculationResponse as SalaryCalculationResponse
from openapi_client.models.salary_item_add_on_employee_request import SalaryItemAddOnEmployeeRequest as SalaryItemAddOnEmployeeRequest
from openapi_client.models.salary_item_add_on_employee_response import SalaryItemAddOnEmployeeResponse as SalaryItemAddOnEmployeeResponse
from openapi_client.models.salary_item_add_on_request import SalaryItemAddOnRequest as SalaryItemAddOnRequest
from openapi_client.models.salary_item_add_on_response import SalaryItemAddOnResponse as SalaryItemAddOnResponse
from openapi_client.models.salary_item_add_on_salary_item_request import SalaryItemAddOnSalaryItemRequest as SalaryItemAddOnSalaryItemRequest
from openapi_client.models.salary_item_page_response import SalaryItemPageResponse as SalaryItemPageResponse
from openapi_client.models.salary_item_response import SalaryItemResponse as SalaryItemResponse
from openapi_client.models.salary_item_response_with_category import SalaryItemResponseWithCategory as SalaryItemResponseWithCategory
from openapi_client.models.salary_item_simple_response import SalaryItemSimpleResponse as SalaryItemSimpleResponse
from openapi_client.models.salary_item_with_salary_item_type_response import SalaryItemWithSalaryItemTypeResponse as SalaryItemWithSalaryItemTypeResponse
from openapi_client.models.salary_payment_detail_company_bank_account_response import SalaryPaymentDetailCompanyBankAccountResponse as SalaryPaymentDetailCompanyBankAccountResponse
from openapi_client.models.salary_payment_detail_response import SalaryPaymentDetailResponse as SalaryPaymentDetailResponse
from openapi_client.models.salary_payment_employee_response import SalaryPaymentEmployeeResponse as SalaryPaymentEmployeeResponse
from openapi_client.models.salary_payment_employment_status_response import SalaryPaymentEmploymentStatusResponse as SalaryPaymentEmploymentStatusResponse
from openapi_client.models.salary_payment_page_response import SalaryPaymentPageResponse as SalaryPaymentPageResponse
from openapi_client.models.salary_payment_response import SalaryPaymentResponse as SalaryPaymentResponse
from openapi_client.models.salary_payment_summary_company_bank_account_response import SalaryPaymentSummaryCompanyBankAccountResponse as SalaryPaymentSummaryCompanyBankAccountResponse
from openapi_client.models.salary_payment_summary_page_response import SalaryPaymentSummaryPageResponse as SalaryPaymentSummaryPageResponse
from openapi_client.models.salary_payment_summary_response import SalaryPaymentSummaryResponse as SalaryPaymentSummaryResponse
from openapi_client.models.salary_template_detail_response import SalaryTemplateDetailResponse as SalaryTemplateDetailResponse
from openapi_client.models.salary_template_page_response import SalaryTemplatePageResponse as SalaryTemplatePageResponse
from openapi_client.models.salary_template_response import SalaryTemplateResponse as SalaryTemplateResponse
from openapi_client.models.severance_payment_plan_page_response import SeverancePaymentPlanPageResponse as SeverancePaymentPlanPageResponse
from openapi_client.models.severance_payment_plan_response import SeverancePaymentPlanResponse as SeverancePaymentPlanResponse
from openapi_client.models.severance_plan_detail_item_request import SeverancePlanDetailItemRequest as SeverancePlanDetailItemRequest
from openapi_client.models.severance_plan_detail_response import SeverancePlanDetailResponse as SeverancePlanDetailResponse
from openapi_client.models.severance_plan_page_response import SeverancePlanPageResponse as SeverancePlanPageResponse
from openapi_client.models.severance_plan_payment_plan_item_request import SeverancePlanPaymentPlanItemRequest as SeverancePlanPaymentPlanItemRequest
from openapi_client.models.severance_plan_request import SeverancePlanRequest as SeverancePlanRequest
from openapi_client.models.severance_plan_response import SeverancePlanResponse as SeverancePlanResponse
from openapi_client.models.severance_plan_response_with_detail import SeverancePlanResponseWithDetail as SeverancePlanResponseWithDetail
from openapi_client.models.shift_pattern_template_detail_item_request import ShiftPatternTemplateDetailItemRequest as ShiftPatternTemplateDetailItemRequest
from openapi_client.models.shift_pattern_template_detail_item_request_shift import ShiftPatternTemplateDetailItemRequestShift as ShiftPatternTemplateDetailItemRequestShift
from openapi_client.models.shift_pattern_template_detail_response import ShiftPatternTemplateDetailResponse as ShiftPatternTemplateDetailResponse
from openapi_client.models.shift_pattern_template_item_response import ShiftPatternTemplateItemResponse as ShiftPatternTemplateItemResponse
from openapi_client.models.shift_pattern_template_list_item_response import ShiftPatternTemplateListItemResponse as ShiftPatternTemplateListItemResponse
from openapi_client.models.shift_pattern_template_page_response import ShiftPatternTemplatePageResponse as ShiftPatternTemplatePageResponse
from openapi_client.models.shift_pattern_template_request import ShiftPatternTemplateRequest as ShiftPatternTemplateRequest
from openapi_client.models.shift_pattern_template_simple_response import ShiftPatternTemplateSimpleResponse as ShiftPatternTemplateSimpleResponse
from openapi_client.models.shift_response import ShiftResponse as ShiftResponse
from openapi_client.models.sort_property import SortProperty as SortProperty
from openapi_client.models.state_list_item_response import StateListItemResponse as StateListItemResponse
from openapi_client.models.state_page_response import StatePageResponse as StatePageResponse
from openapi_client.models.state_request import StateRequest as StateRequest
from openapi_client.models.state_response import StateResponse as StateResponse
from openapi_client.models.sub_location_location_response import SubLocationLocationResponse as SubLocationLocationResponse
from openapi_client.models.sub_location_page_response import SubLocationPageResponse as SubLocationPageResponse
from openapi_client.models.sub_location_request import SubLocationRequest as SubLocationRequest
from openapi_client.models.sub_location_response import SubLocationResponse as SubLocationResponse
from openapi_client.models.tax_amount_response import TaxAmountResponse as TaxAmountResponse
from openapi_client.models.tax_and_allowance_response import TaxAndAllowanceResponse as TaxAndAllowanceResponse
from openapi_client.models.tax_calculation_detail_response import TaxCalculationDetailResponse as TaxCalculationDetailResponse
from openapi_client.models.tax_calculation_income_request import TaxCalculationIncomeRequest as TaxCalculationIncomeRequest
from openapi_client.models.tax_calculation_page_response import TaxCalculationPageResponse as TaxCalculationPageResponse
from openapi_client.models.tax_calculation_request import TaxCalculationRequest as TaxCalculationRequest
from openapi_client.models.tax_calculation_response import TaxCalculationResponse as TaxCalculationResponse
from openapi_client.models.tax_dependent_request import TaxDependentRequest as TaxDependentRequest
from openapi_client.models.tax_dependent_response import TaxDependentResponse as TaxDependentResponse
from openapi_client.models.tax_income_response import TaxIncomeResponse as TaxIncomeResponse
from openapi_client.models.tax_membership_history_response import TaxMembershipHistoryResponse as TaxMembershipHistoryResponse
from openapi_client.models.tax_membership_period_response import TaxMembershipPeriodResponse as TaxMembershipPeriodResponse
from openapi_client.models.tax_membership_response import TaxMembershipResponse as TaxMembershipResponse
from openapi_client.models.tax_membership_tax_subject_request import TaxMembershipTaxSubjectRequest as TaxMembershipTaxSubjectRequest
from openapi_client.models.tax_report1721_a1_page_response import TaxReport1721A1PageResponse as TaxReport1721A1PageResponse
from openapi_client.models.tax_report1721_a1_response import TaxReport1721A1Response as TaxReport1721A1Response
from openapi_client.models.tax_report1721_vi_detail_response import TaxReport1721VIDetailResponse as TaxReport1721VIDetailResponse
from openapi_client.models.tax_report1721_viii_page_response import TaxReport1721VIIIPageResponse as TaxReport1721VIIIPageResponse
from openapi_client.models.tax_report1721_viii_response import TaxReport1721VIIIResponse as TaxReport1721VIIIResponse
from openapi_client.models.tax_report1721_vii_page_response import TaxReport1721VIIPageResponse as TaxReport1721VIIPageResponse
from openapi_client.models.tax_report1721_vii_response import TaxReport1721VIIResponse as TaxReport1721VIIResponse
from openapi_client.models.tax_report1721_vi_page_response import TaxReport1721VIPageResponse as TaxReport1721VIPageResponse
from openapi_client.models.tax_report1721_vi_response import TaxReport1721VIResponse as TaxReport1721VIResponse
from openapi_client.models.temporary_monthly_tax_calculation_simulator_response import TemporaryMonthlyTaxCalculationSimulatorResponse as TemporaryMonthlyTaxCalculationSimulatorResponse
from openapi_client.models.termination_bpjs_manpower_reason_page_response import TerminationBPJSManpowerReasonPageResponse as TerminationBPJSManpowerReasonPageResponse
from openapi_client.models.termination_bpjs_manpower_reason_response import TerminationBPJSManpowerReasonResponse as TerminationBPJSManpowerReasonResponse
from openapi_client.models.termination_entry_request import TerminationEntryRequest as TerminationEntryRequest
from openapi_client.models.termination_entry_response import TerminationEntryResponse as TerminationEntryResponse
from openapi_client.models.termination_reason_category_page_response import TerminationReasonCategoryPageResponse as TerminationReasonCategoryPageResponse
from openapi_client.models.termination_reason_category_response import TerminationReasonCategoryResponse as TerminationReasonCategoryResponse
from openapi_client.models.termination_reason_detail_response import TerminationReasonDetailResponse as TerminationReasonDetailResponse
from openapi_client.models.termination_reason_page_response import TerminationReasonPageResponse as TerminationReasonPageResponse
from openapi_client.models.termination_reason_request import TerminationReasonRequest as TerminationReasonRequest
from openapi_client.models.termination_reason_response import TerminationReasonResponse as TerminationReasonResponse
from openapi_client.models.termination_tax_reason_page_response import TerminationTaxReasonPageResponse as TerminationTaxReasonPageResponse
from openapi_client.models.termination_tax_reason_response import TerminationTaxReasonResponse as TerminationTaxReasonResponse
from openapi_client.models.time_allowance_detail_response import TimeAllowanceDetailResponse as TimeAllowanceDetailResponse
from openapi_client.models.time_allowance_details_response import TimeAllowanceDetailsResponse as TimeAllowanceDetailsResponse
from openapi_client.models.time_zone_response import TimeZoneResponse as TimeZoneResponse
from openapi_client.models.transition_calculation_count_response import TransitionCalculationCountResponse as TransitionCalculationCountResponse
from openapi_client.models.transition_calculation_details_amount_request import TransitionCalculationDetailsAmountRequest as TransitionCalculationDetailsAmountRequest
from openapi_client.models.transition_calculation_details_request import TransitionCalculationDetailsRequest as TransitionCalculationDetailsRequest
from openapi_client.models.transition_calculation_employee_salary_template_response import TransitionCalculationEmployeeSalaryTemplateResponse as TransitionCalculationEmployeeSalaryTemplateResponse
from openapi_client.models.transition_calculation_response import TransitionCalculationResponse as TransitionCalculationResponse
from openapi_client.models.transition_calculation_salary_template_detail_response import TransitionCalculationSalaryTemplateDetailResponse as TransitionCalculationSalaryTemplateDetailResponse
from openapi_client.models.transition_time_allowance_detail_response import TransitionTimeAllowanceDetailResponse as TransitionTimeAllowanceDetailResponse
from openapi_client.models.unprocessable_content_response import UnprocessableContentResponse as UnprocessableContentResponse
from openapi_client.models.unprocessable_message import UnprocessableMessage as UnprocessableMessage
from openapi_client.models.unprocessed_transition_calculation_page_response import UnprocessedTransitionCalculationPageResponse as UnprocessedTransitionCalculationPageResponse
from openapi_client.models.unprocessed_transition_calculation_response import UnprocessedTransitionCalculationResponse as UnprocessedTransitionCalculationResponse
from openapi_client.models.update_bank_account_configuration_request import UpdateBankAccountConfigurationRequest as UpdateBankAccountConfigurationRequest
from openapi_client.models.user_and_role_response import UserAndRoleResponse as UserAndRoleResponse
from openapi_client.models.user_page_response import UserPageResponse as UserPageResponse
from openapi_client.models.user_response import UserResponse as UserResponse
from openapi_client.models.widget_content_response import WidgetContentResponse as WidgetContentResponse
from openapi_client.models.widget_page_response import WidgetPageResponse as WidgetPageResponse
from openapi_client.models.widget_response import WidgetResponse as WidgetResponse
from openapi_client.models.workday_configuration_detail_response import WorkdayConfigurationDetailResponse as WorkdayConfigurationDetailResponse
from openapi_client.models.workflow_activity_page_response import WorkflowActivityPageResponse as WorkflowActivityPageResponse
from openapi_client.models.workflow_activity_response import WorkflowActivityResponse as WorkflowActivityResponse
from openapi_client.models.workflow_reason_category_page_response import WorkflowReasonCategoryPageResponse as WorkflowReasonCategoryPageResponse
from openapi_client.models.workflow_reason_category_request import WorkflowReasonCategoryRequest as WorkflowReasonCategoryRequest
from openapi_client.models.workflow_reason_category_response import WorkflowReasonCategoryResponse as WorkflowReasonCategoryResponse
from openapi_client.models.workflow_reason_page_response import WorkflowReasonPageResponse as WorkflowReasonPageResponse
from openapi_client.models.workflow_reason_request import WorkflowReasonRequest as WorkflowReasonRequest
from openapi_client.models.workflow_reason_response import WorkflowReasonResponse as WorkflowReasonResponse
from openapi_client.models.workflow_template_response import WorkflowTemplateResponse as WorkflowTemplateResponse
from openapi_client.models.workgroup_workday_configuration_page_response import WorkgroupWorkdayConfigurationPageResponse as WorkgroupWorkdayConfigurationPageResponse
from openapi_client.models.workgroup_workday_configuration_request import WorkgroupWorkdayConfigurationRequest as WorkgroupWorkdayConfigurationRequest
from openapi_client.models.workgroup_workday_configuration_response import WorkgroupWorkdayConfigurationResponse as WorkgroupWorkdayConfigurationResponse




"""CATAPA Authentication Module.

This module handles OAuth2 authentication for the CATAPA API,
supporting client credentials flow with automatic token refresh.

Authors:
    Handrian Alandi (handrian.alandi@gdplabs.id)

References:
    [1] https://developer.catapa.com/#section/Authentication
"""

import time
from dataclasses import dataclass
from typing import Any

import requests
from catapa.auth.constant import ONE_HOUR_IN_SECONDS, TOKEN_EXPIRATION_BUFFER_SECONDS
from requests.auth import HTTPBasicAuth


class CatapaAuthError(Exception):
    """Exception raised for CATAPA authentication errors.

    This exception is raised when authentication fails, such as when
    the OAuth2 token request fails or returns an error response.
    """

    pass

@dataclass
class CatapaConfig:
    """Configuration for CATAPA API authentication."""
    tenant: str
    client_id: str
    client_secret: str
    base_url: str = "https://api.catapa.com"


@dataclass
class TokenInfo:
    """Internal token storage with expiration tracking."""
    access_token: str
    token_type: str
    expires_at: float  # timestamp in seconds


class CatapaAuth:
    """Handles OAuth2 authentication for CATAPA API.

    Features:
    - Automatic token refresh with 5-minute buffer
    - Thread-safe token management
    - Client credentials flow support

    Attributes:
        config (CatapaConfig): Configuration for CATAPA API authentication.
        _token_info (TokenInfo | None): Internal token storage with expiration tracking.

    Example:
        auth = CatapaAuth(CatapaConfig(
            tenant="your-tenant",
            client_id="your-client-id",
            client_secret="your-client-secret"
        ))

        token = auth.get_access_token()
    """

    def __init__(self, config: CatapaConfig) -> None:
        """Initialize the CATAPA authentication instance.

        Args:
            config (CatapaConfig): Configuration for CATAPA API authentication.
        """
        self.config = config
        self._token_info: TokenInfo | None = None

    def get_access_token(self) -> str:
        """Get a valid access token, refreshing if necessary.

        Returns:
            str: Valid access token

        Raises:
            CatapaAuthError: If authentication fails
        """
        # If we have a valid token, return it
        if self._token_info and self._is_token_valid():
            return self._token_info.access_token

        # Refresh the token
        return self._fetch_new_token()

    def refresh_token(self) -> None:
        """Force refresh the access token."""
        self._token_info = None
        self.get_access_token()

    def _is_token_valid(self) -> bool:
        """Check if current token is valid (not expired).

        Returns:
            bool: True if token is valid, False otherwise
        """
        if not self._token_info:
            return False

        # Add buffer before expiration to ensure token is refreshed in time
        return time.time() < (self._token_info.expires_at - TOKEN_EXPIRATION_BUFFER_SECONDS)

    def _fetch_new_token(self) -> str:
        """Fetch a new access token from the OAuth2 endpoint.

        Returns:
            str: New access token

        Raises:
            CatapaAuthError: If authentication fails
        """
        url = f"{self.config.base_url}/oauth/token"

        headers = {
            "Tenant": self.config.tenant,
            "Content-Type": "application/x-www-form-urlencoded",
            "Accept": "application/json"
        }

        data = {
            "grant_type": "client_credentials"
        }

        try:
            response = requests.post(
                url,
                headers=headers,
                data=data,
                auth=HTTPBasicAuth(self.config.client_id, self.config.client_secret)
            )
            response.raise_for_status()

            token_response = response.json()

            # Store token with expiration info
            self._token_info = TokenInfo(
                access_token=token_response["access_token"],
                token_type=token_response.get("token_type", "Bearer"),
                expires_at=time.time() + token_response.get("expires_in", ONE_HOUR_IN_SECONDS)
            )

            return self._token_info.access_token

        except requests.exceptions.RequestException as e:
            raise CatapaAuthError(f"Failed to obtain access token: {str(e)}") from e

    def validate_token(self, access_token: str | None = None) -> bool:
        """Validate access token using dedicated endpoint.

        Args:
            access_token (str | None, optional): Token to validate. If None, uses current token. Defaults to None.

        Returns:
            bool: True if token is valid, False otherwise
        """
        token = access_token or (self._token_info.access_token if self._token_info else None)
        if not token:
            return False

        url = f"{self.config.base_url}/v1/oauth-clients/validate-access-token"

        try:
            response = requests.get(
                url,
                headers={
                    "Tenant": self.config.tenant,
                    "Authorization": f"Bearer {token}"
                }
            )
            return response.ok  # 200 OK means valid, 401 means invalid
        except requests.exceptions.RequestException:
            # If validation endpoint fails, assume token is invalid
            return False

    def get_token_info(self) -> dict[str, Any] | None:
        """Get current token info for debugging/monitoring.

        Returns:
            dict[str, Any] | None: Token information or None if no token
        """
        if not self._token_info:
            return None

        return {
            "access_token": self._token_info.access_token[:5] + "..." + self._token_info.access_token[-5:],
            "token_type": self._token_info.token_type,
            "expires_at": self._token_info.expires_at,
            "is_valid": self._is_token_valid()
        }

    def clear_token(self) -> None:
        """Clear stored token (useful for logout)."""
        self._token_info = None



# coding: utf-8

"""
    CATAPA API

    # Introduction CATAPA API uses RESTful API style. It uses JSON data format for data exchange and utilizes HTTP verbs as appropriate.  For authorization & authentication, CATAPA API uses OAuth 2.0 protocol.  # Base URL Production: https://api.catapa.com  # Authentication Clients need to acquire an access token before they send HTTP requests to resource endpoints.  <SecurityDefinitions />  ## Validate Access Token    Use this endpoint to verify if an access token is valid and was issued by the API gateway. The endpoint supports both user tokens and client credentials tokens.    | **HTTP Method**  | `GET`                                                |                                         |   |------------------|------------------------------------------------------|-----------------------------------------|   | **URL**          | `<base-url>/v1/oauth-clients/validate-access-token`  |                                         |   | **Headers**      | `Authorization`                                      | `Bearer <access-token>`                 |   |                  | `Tenant`                                             | Your tenant identifier (e.g., \"catapa\") |  ### Example request using `curl`    ```bash   curl --location '<base-url>/v1/oauth-clients/validate-access-token' \\     --header 'Tenant: catapa' \\     --header 'Authorization: Bearer <access-token>'   ```  ### Response codes  - **200 OK**: Token is valid - **401 Unauthorized**: Token is invalid or expired  ### Notes  - This endpoint validates both user authentication tokens and client credentials tokens - For server-to-server communication, use client credentials flow with the token in the Authorization header - No response body is returned; the status code indicates the validation result - The `Tenant` header is required to specify which tenant context to validate the token against  # HTTP Headers Each request should contain the following headers.  |Headers        |Description  | |---------------|-------------| |Tenant         |Tenant name. e.g. Catapa| |Authorization  |For authentication. Value format: Bearer <access-token>|  Example HTTP Request using cURL: ```bash curl <base-url>/core/v1/employees?page=0&size=10 \\ -H \"Tenant: <tenant name>\" \\ -H \"Authorization: Bearer <access-token>\" ```  # Rate Limit To ensure optimal API performance and fair usage for all users, we implement rate limiting. The general limit is **400 requests per minute, per Client ID**. If you exceed the rate limit, you will receive an HTTP 429 (Too Many Requests) error response.  # Pagination The API provides `page` & `size` query params. `page` is a page number starting from 0. `size` is number of elements per page. Maximum value of `size` is 50.  Every paginated endpoints will have following response format: ``` {   \"content\": [     { ... },     { ... }   ],   \"number\": 0, // page number   \"size\": 10, // page size   \"numberOfElements\": 10, // number of element in this current page   \"totalElements\": 100,   \"totalPages\": 10 } ```  # Search Query You can perform search operations in some endpoints by setting the query parameter. Query value parameter constructed with following format:  ```bash ?query=<key><operator><value>,<key><operator><value> ```  Explanations: | Format | Descriptions | |-|-| | `<key>` | Key name to search certain fields | | `<operator>`   | Operation to apply on certain fields.<br>Supported operators: `:` `<` `>` | | `<value>` | Value to apply on search. **Value should be encoded using URL encoder**. For examples:<br><br>Plain: `John Doe`<br>Encoded: `John%20Doe` | | `,` | AND operator |   For example, the `/core/v1/employees` endpoint has following search query. |Key                    |Supported Operators  |Notes  | |-----------------------|---------------------|-------| |identificationNumberIn | `:`                 |Equal operator with multiple values. Each value should separated with delimiters `;`| |name                   | `:`                 |Like operator| |startDate              | `:`<br/>`>`<br/>`<` |Equal<br>Greater than or equal to<br>Less than or equal to|  Clients can construct search query with these following variations:  1. Search an employee with ID number 1111 ```bash curl <base-url>/core/v1/employees?query=identificationNumberIn:1111 ``` 1. Search multiple employees with ID number 1111 and 2222 ```bash curl <base-url>/core/v1/employees?query=identificationNumberIn:1111;2222 ``` 1. Search employees with name `John Doe` ```bash curl <base-url>/core/v1/employees?query=name:John%20Doe ``` 1. Search all employees with start date between 2020-01-01 and 2020-12-31: ```bash curl <base-url>/core/v1/employees?query=startDate>2020-01-01,startDate<2020-12-31 ``` 

    The version of the OpenAPI document: 1.0.0
    Contact: support@catapa.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import io
import json
import re
import ssl

import urllib3

from openapi_client.exceptions import ApiException, ApiValueError

SUPPORTED_SOCKS_PROXIES = {"socks5", "socks5h", "socks4", "socks4a"}
RESTResponseType = urllib3.HTTPResponse


def is_socks_proxy_url(url):
    if url is None:
        return False
    split_section = url.split("://")
    if len(split_section) < 2:
        return False
    else:
        return split_section[0].lower() in SUPPORTED_SOCKS_PROXIES


class RESTResponse(io.IOBase):

    def __init__(self, resp) -> None:
        self.response = resp
        self.status = resp.status
        self.reason = resp.reason
        self.data = None

    def read(self):
        if self.data is None:
            self.data = self.response.data
        return self.data

    @property
    def headers(self):
        """Returns a dictionary of response headers."""
        return self.response.headers

    def getheaders(self):
        """Returns a dictionary of the response headers; use ``headers`` instead."""
        return self.response.headers

    def getheader(self, name, default=None):
        """Returns a given response header; use ``headers.get()`` instead."""
        return self.response.headers.get(name, default)


class RESTClientObject:

    def __init__(self, configuration) -> None:
        # urllib3.PoolManager will pass all kw parameters to connectionpool
        # https://github.com/shazow/urllib3/blob/f9409436f83aeb79fbaf090181cd81b784f1b8ce/urllib3/poolmanager.py#L75  # noqa: E501
        # https://github.com/shazow/urllib3/blob/f9409436f83aeb79fbaf090181cd81b784f1b8ce/urllib3/connectionpool.py#L680  # noqa: E501
        # Custom SSL certificates and client certificates: http://urllib3.readthedocs.io/en/latest/advanced-usage.html  # noqa: E501

        # cert_reqs
        if configuration.verify_ssl:
            cert_reqs = ssl.CERT_REQUIRED
        else:
            cert_reqs = ssl.CERT_NONE

        pool_args = {
            "cert_reqs": cert_reqs,
            "ca_certs": configuration.ssl_ca_cert,
            "cert_file": configuration.cert_file,
            "key_file": configuration.key_file,
            "ca_cert_data": configuration.ca_cert_data,
        }
        if configuration.assert_hostname is not None:
            pool_args['assert_hostname'] = (
                configuration.assert_hostname
            )

        if configuration.retries is not None:
            pool_args['retries'] = configuration.retries

        if configuration.tls_server_name:
            pool_args['server_hostname'] = configuration.tls_server_name


        if configuration.socket_options is not None:
            pool_args['socket_options'] = configuration.socket_options

        if configuration.connection_pool_maxsize is not None:
            pool_args['maxsize'] = configuration.connection_pool_maxsize

        # https pool manager
        self.pool_manager: urllib3.PoolManager

        if configuration.proxy:
            if is_socks_proxy_url(configuration.proxy):
                from urllib3.contrib.socks import SOCKSProxyManager
                pool_args["proxy_url"] = configuration.proxy
                pool_args["headers"] = configuration.proxy_headers
                self.pool_manager = SOCKSProxyManager(**pool_args)
            else:
                pool_args["proxy_url"] = configuration.proxy
                pool_args["proxy_headers"] = configuration.proxy_headers
                self.pool_manager = urllib3.ProxyManager(**pool_args)
        else:
            self.pool_manager = urllib3.PoolManager(**pool_args)

    def request(
        self,
        method,
        url,
        headers=None,
        body=None,
        post_params=None,
        _request_timeout=None
    ):
        """Perform requests.

        :param method: http request method
        :param url: http request url
        :param headers: http request headers
        :param body: request json body, for `application/json`
        :param post_params: request post parameters,
                            `application/x-www-form-urlencoded`
                            and `multipart/form-data`
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        """
        method = method.upper()
        assert method in [
            'GET',
            'HEAD',
            'DELETE',
            'POST',
            'PUT',
            'PATCH',
            'OPTIONS'
        ]

        if post_params and body:
            raise ApiValueError(
                "body parameter cannot be used with post_params parameter."
            )

        post_params = post_params or {}
        headers = headers or {}

        timeout = None
        if _request_timeout:
            if isinstance(_request_timeout, (int, float)):
                timeout = urllib3.Timeout(total=_request_timeout)
            elif (
                    isinstance(_request_timeout, tuple)
                    and len(_request_timeout) == 2
                ):
                timeout = urllib3.Timeout(
                    connect=_request_timeout[0],
                    read=_request_timeout[1]
                )

        try:
            # For `POST`, `PUT`, `PATCH`, `OPTIONS`, `DELETE`
            if method in ['POST', 'PUT', 'PATCH', 'OPTIONS', 'DELETE']:

                # no content type provided or payload is json
                content_type = headers.get('Content-Type')
                if (
                    not content_type
                    or re.search('json', content_type, re.IGNORECASE)
                ):
                    request_body = None
                    if body is not None:
                        request_body = json.dumps(body)
                    r = self.pool_manager.request(
                        method,
                        url,
                        body=request_body,
                        timeout=timeout,
                        headers=headers,
                        preload_content=False
                    )
                elif content_type == 'application/x-www-form-urlencoded':
                    r = self.pool_manager.request(
                        method,
                        url,
                        fields=post_params,
                        encode_multipart=False,
                        timeout=timeout,
                        headers=headers,
                        preload_content=False
                    )
                elif content_type == 'multipart/form-data':
                    # must del headers['Content-Type'], or the correct
                    # Content-Type which generated by urllib3 will be
                    # overwritten.
                    del headers['Content-Type']
                    # Ensures that dict objects are serialized
                    post_params = [(a, json.dumps(b)) if isinstance(b, dict) else (a,b) for a, b in post_params]
                    r = self.pool_manager.request(
                        method,
                        url,
                        fields=post_params,
                        encode_multipart=True,
                        timeout=timeout,
                        headers=headers,
                        preload_content=False
                    )
                # Pass a `string` parameter directly in the body to support
                # other content types than JSON when `body` argument is
                # provided in serialized form.
                elif isinstance(body, str) or isinstance(body, bytes):
                    r = self.pool_manager.request(
                        method,
                        url,
                        body=body,
                        timeout=timeout,
                        headers=headers,
                        preload_content=False
                    )
                elif headers['Content-Type'].startswith('text/') and isinstance(body, bool):
                    request_body = "true" if body else "false"
                    r = self.pool_manager.request(
                        method,
                        url,
                        body=request_body,
                        preload_content=False,
                        timeout=timeout,
                        headers=headers)
                else:
                    # Cannot generate the request from given parameters
                    msg = """Cannot prepare a request message for provided
                             arguments. Please check that your arguments match
                             declared content type."""
                    raise ApiException(status=0, reason=msg)
            # For `GET`, `HEAD`
            else:
                r = self.pool_manager.request(
                    method,
                    url,
                    fields={},
                    timeout=timeout,
                    headers=headers,
                    preload_content=False
                )
        except urllib3.exceptions.SSLError as e:
            msg = "\n".join([type(e).__name__, str(e)])
            raise ApiException(status=0, reason=msg)

        return RESTResponse(r)
